py-dag
======

Python implementation of directed acyclic graph

![](https://travis-ci.org/thieman/py-dag.svg?branch=master)

This library is [largely provided as-is](https://github.com/thieman/py-dag/issues/17#issuecomment-193371191). Breaking changes may happen without warning. If you choose to use it, you should peg your dependencies to a specific version.
